@@ -4,6 +4,9 @@
 /* Define the canonical hostname */
 #undef CANONICAL_HOST
 
+/* Define if we want to use LINEMODE */
+#undef LINEMODE
+
 /* Define if struct utmp has member ut_host */
 #undef HAVE_UT_HOST
 
