@@ -53,21 +53,6 @@ static char sccsid[] = "@(#)inet_addr.c	5.11 (Berkeley) 12/9/91";
 #define	INADDR_NONE		0xffffffff		/* -1 return */
 #endif
 
-/*
- * Ascii internet address interpretation routine.
- * The value returned is in network order.
- */
-u_long
-inet_addr(cp)
-	register const char *cp;
-{
-	struct in_addr val;
-
-	if (inet_aton(cp, &val))
-		return (val.s_addr);
-	return (INADDR_NONE);
-}
-
 /* 
  * Check whether "cp" is a valid ascii representation
  * of an Internet address and convert to a binary address.
@@ -75,7 +60,7 @@ inet_addr(cp)
  * This replaces inet_addr, the return value from which
  * cannot distinguish between failure and a local broadcast address.
  */
-#if linux
+#if defined(linux) || defined(sgi) || defined(__NetBSD__)
 int
 #else
 unsigned long
@@ -166,4 +151,23 @@ inet_aton(cp, addr)
 	return (1);
 }
 
+/*
+ * Ascii internet address interpretation routine.
+ * The value returned is in network order.
+ */
+#ifdef __alpha
+unsigned int
+#else
+u_long
+#endif
+inet_addr(cp)
+	register const char *cp;
+{
+	struct in_addr val;
+
+	if (inet_aton(cp, &val))
+		return (val.s_addr);
+	return (INADDR_NONE);
+}
+
 #endif 
