@@ -55,10 +55,10 @@ static char sccsid[] = "@(#)auth.c	8.1 (Berkeley) 6/4/93";
  * or implied warranty.
  */
 
-/* 	$Id: auth.c,v 1.3 1995/11/14 14:29:25 martin Exp $	 */
+/* 	$Id: auth.c,v 1.3 1995/11/14 14:29:25 martin Exp martin $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: auth.c,v 1.3 1995/11/14 14:29:25 martin Exp $";
+static char vcid[] = "$Id: auth.c,v 1.3 1995/11/14 14:29:25 martin Exp martin $";
 #endif /* lint */
 
 #include "../../config.h"
@@ -263,7 +263,7 @@ auth_disable_name(name)
 	char *name;
 {
 	int x;
-	for (x = 0; x < AUTHTYPE_CNT; ++x) {
+	for (x = 0; x < AUTHTYPE_COUNT; ++x) {
 		if (!strcasecmp(name, AUTHTYPE_NAME(x))) {
 			i_wont_support |= typemask(x);
 			break;
@@ -283,7 +283,7 @@ getauthmask(type, maskp)
 		return(1);
 	}
 
-	for (x = 1; x < AUTHTYPE_CNT; ++x) {
+	for (x = 1; x < AUTHTYPE_COUNT; ++x) {
 		if (!strcasecmp(type, AUTHTYPE_NAME(x))) {
 			*maskp = typemask(x);
 			return(1);
