@@ -35,10 +35,10 @@
 static char sccsid[] = "@(#)telnet.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: telnet.c,v 1.3 1995/11/15 08:40:03 martin Exp martin $	 */
+/* 	$Id: telnet.c,v 1.5 1996/02/01 12:07:31 martin Exp $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: telnet.c,v 1.3 1995/11/15 08:40:03 martin Exp martin $";
+static char vcid[] = "$Id: telnet.c,v 1.5 1996/02/01 12:07:31 martin Exp $";
 #endif /* lint */
 
 #include "../config.h"
@@ -810,8 +810,10 @@ setupterm(tname, fd, errp)
 }
 #else
 #define	termbuf	ttytype
+#if !defined(__NetBSD__)
 extern char ttytype[];
 #endif
+#endif
 
 int resettermname = 1;
 
@@ -899,14 +901,14 @@ suboption()
 	if (SB_EOF())
 	    return;
 	if (SB_GET() == TELQUAL_SEND) {
-	    long ospeed, ispeed;
+	    long xospeed, ispeed;
 	    unsigned char temp[50];
 	    int len;
 
-	    TerminalSpeeds(&ispeed, &ospeed);
+	    TerminalSpeeds(&ispeed, &xospeed);
 
 	    sprintf((char *)temp, "%c%c%c%c%d,%d%c%c", IAC, SB, TELOPT_TSPEED,
-		    TELQUAL_IS, ospeed, ispeed, IAC, SE);
+		    TELQUAL_IS, xospeed, ispeed, IAC, SE);
 	    len = strlen((char *)temp+4) + 4;	/* temp[3] is 0 ... */
 
 	    if (len < NETROOM()) {
@@ -2307,7 +2309,12 @@ telnet(user)
 		local_host[sizeof(local_host)-1] = 0;
 	}
 	auth_encrypt_init(local_host, hostname, "TELNET", 0);
-	auth_encrypt_user(user);
+#if	defined(AUTHENTICATION)
+	if(autologin)
+	    auth_sendname(user,strlen(user));
+	else
+#endif
+	    auth_encrypt_user(user);
     }
 #endif	/* defined(AUTHENTICATION) || defined(ENCRYPTION)  */
 #   if !defined(TN3270)
