@@ -35,10 +35,10 @@
 static char sccsid[] = "@(#)sys_term.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: sys_term.c,v 1.5 1995/11/23 15:43:35 martin Exp martin $	 */
+/* 	$Id: sys_term.c,v 1.8 1996/02/01 12:08:26 martin Exp martin $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: sys_term.c,v 1.5 1995/11/23 15:43:35 martin Exp martin $";
+static char vcid[] = "$Id: sys_term.c,v 1.8 1996/02/01 12:08:26 martin Exp martin $";
 #endif /* lint */
 
 #include "telnetd.h"
@@ -155,18 +155,6 @@ extern struct sysv sysv;
 #if defined(UNICOS5) && defined(CRAY2) && !defined(EXTPROC)
 # define EXTPROC 0400
 #endif
-#if defined(_AIX)
-# define EXTPROC 0400
-#endif
-#if defined(linux)
-# define EXTPROC 0400
-#endif
-#if defined(__alpha)
-# define EXTPROC 0400
-#endif
-#if defined(__ultrix)
-# define TS_EXTPROC 0400
-#endif
 
 #ifdef __hpux
 #undef TIOCSCTTY
