@@ -47,10 +47,10 @@ static char copyright[] =
 static char sccsid[] = "@(#)telnetd.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: telnetd.c,v 1.4 1995/11/23 15:43:46 martin Exp martin $	 */
+/* 	$Id: telnetd.c,v 1.7 1996/02/01 12:08:47 martin Exp $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: telnetd.c,v 1.4 1995/11/23 15:43:46 martin Exp martin $";
+static char vcid[] = "$Id: telnetd.c,v 1.7 1996/02/01 12:08:47 martin Exp $";
 #endif /* lint */
 
 #include "telnetd.h"
@@ -823,7 +823,9 @@ getterminaltype(name)
 #endif /* TJH_FORCED_FLUSH */
     }
     if (his_state_is_will(TELOPT_AUTHENTICATION)) {
+      logprintf("getterminaltype: ssl_active_flag %d\n", ssl_active_flag);
 	retval = auth_wait(name);
+      logprintf("getterminaltype: ssl_active_flag %d\n", ssl_active_flag);
     }
 
 #ifdef USE_SSL
@@ -1147,6 +1149,7 @@ doit(who)
 
 #ifdef USE_SSL
 	if (debug) {
+	  logprintf("doit: level %s, user_name %s\n", level, user_name);
 	    fprintf(stderr,"doit - starting telnet protocol itself\n");
 	    fflush(stderr);
 	    sleep(2);
